==> weblog-1_41.tar.gz: weblog/language/japanese/blocks.php <==
<?php
/*
 * $Id: blocks.php,v 1.7 2005/04/13 06:18:31 tohokuaiki Exp $
 * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
 * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.zive.net/)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */
/*
 * version j0.90 2003/05/18 JST
 * Traslated into Japanese by wellwine (http://wellwine.zive.net)
 * Copyright (c) 2003 by wellwine
 */

define('_MB_WEBLOG_EDIT_NUMBER_OF_ENTRIES','ɽ륨ȥ');
define('_MB_WEBLOG_EDIT_LINK_TO_LIST', 'ɮ̾򥨥ȥꥹȤ˥󥯤(0=,1=Ϥ)');
define('_MB_WEBLOG_EDIT_MAX_TITLE_LENGTH','ɽȥĹ');
define('_MB_WEBLOG_EDIT_MAX_CONTENTS_LENGTH','ɽƥĹ');
define('_MB_WEBLOG_EDIT_DATE_FORMAT','ս');
define('_MB_WEBLOG_EDIT_USE_AVATARS','ХѤ(0=,1=Ϥ)');
define('_MB_WEBLOG_EDIT_TYPE','(1=,2=,3=)');

define('_MB_WEBLOG_EDIT_NUMBER_OF_USERS', 'ɽ桼ο');
define('_MB_WEBLOG_EDIT_NUMBER_OF_TRACKBACKS', 'ɽȥåХåο');
define('_MB_WEBLOG_EDIT_NUMBER_OF_COMMENTS', 'ɽ륳Ȥο');
define('_MB_WEBLOG_EDIT_ORDER_BY', 'ɽ(0=ǽ,1=פα)');
define('_MB_WEBLOG_EDIT_LINKS_MODULE', 'Ȥ󥯥⥸塼<br />(mylinksweblinksȤޤ)');
define('_MB_WEBLOG_EDIT_LINKS_NUMBER', 'ɽ󥯤ο');
define('_MB_WEBLOG_EDIT_LINKS_ONLYPOST', 'ƼԤ֥ƤΤɽ(0= , 1=Ϥ)');
define('_MB_WEBLOG_EDIT_LINKS_SHOWDSC', '󥯤ɽ(0= , 1=Ϥ)');

define('_MB_WEBLOG_LANG_TITLE', 'ȥ');
define('_MB_WEBLOG_LANG_ENTRIES', 'ǶΥȥ');
define('_MB_WEBLOG_LANG_AUTHOR', 'ɮ');
define('_MB_WEBLOG_LANG_COMMENTS', 'ȿ');
define('_MB_WEBLOG_LANG_POSTED', '');
define('_MB_WEBLOG_LANG_READS', '');
define('_MB_WEBLOG_LANG_MOREWEBLOGS', '֥');
define('_MB_WEBLOG_LANG_TRACKBACKS', 'ȥåХå'); //eng
define('_MB_WEBLOG_LANG_TB_TITLE', 'ȥ');
define('_MB_WEBLOG_LANG_TB_WEBLOGTITLE', 'ȥåХåȥ');
define('_MB_WEBLOG_LANG_TB_BLOGNAME', '֥̾');
define('_MB_WEBLOG_LANG_TB_POSTED', '');
define('_MB_WEBLOG_LANG_COM_TITLE', '');
define('_MB_WEBLOG_LANG_COM_UNAME', '桼');
define('_MB_WEBLOG_LANG_COM_WEBLOGTITLE', 'ȤΥȥ');
define('_MB_WEBLOG_LANG_COM_POSTED', '');
define('_MB_WEBLOG_LANG_LINKS_FOR','%sΥ');
define('_MB_WEBLOG_LANG_LINKS_FOR_EVERYONE','󥯽');

define('_MB_WEBLOG_USERS_SORT_READS', '߷ױ');
define('_MB_WEBLOG_USERS_SORT_UPDATE', 'ǽ');
?>

==> weblog-1_42.tar.gz: weblog/language/japanese/blocks.php <==
<?php
/*
 * $Id: blocks.php,v 1.11 2005/08/14 06:15:44 tohokuaiki Exp $
 * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
 * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.zive.net/)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */
/*
 * version j0.90 2003/05/18 JST
 * Traslated into Japanese by wellwine (http://wellwine.zive.net)
 * Copyright (c) 2003 by wellwine
 */

if( defined( 'FOR_XOOPS_LANG_CHECKER' ) || ! defined( 'WEBLOG_MB_LOADED' ) ) {

define( 'WEBLOG_MB_LOADED' , 1 ) ;

define('_MB_WEBLOG_EDIT_NUMBER_OF_ENTRIES','ɽ륨ȥ');
define('_MB_WEBLOG_EDIT_LINK_TO_LIST', 'ɮ̾򥨥ȥꥹȤ˥󥯤(0=,1=Ϥ)');
define('_MB_WEBLOG_EDIT_MAX_TITLE_LENGTH','ɽȥĹ');
define('_MB_WEBLOG_EDIT_MAX_CONTENTS_LENGTH','ɽƥĹ(0ξɽ-1ǥȥȾʬɽ)');
define('_MB_WEBLOG_EDIT_DATE_FORMAT','ս');
define('_MB_WEBLOG_EDIT_USE_AVATARS','ХѤ(0=,1=Ϥ)');
define('_MB_WEBLOG_EDIT_TYPE','(1=,2=,3=)');

define('_MB_WEBLOG_EDIT_NUMBER_OF_USERS', 'ɽ桼ο');
define('_MB_WEBLOG_EDIT_NUMBER_OF_TRACKBACKS', 'ɽȥåХåο');
define('_MB_WEBLOG_EDIT_NUMBER_OF_COMMENTS', 'ɽ륳Ȥο');
define('_MB_WEBLOG_EDIT_ORDER_BY', 'ɽ(0=ǽ,1=פα)');
define('_MB_WEBLOG_EDIT_LINKS_MODULE', 'Ȥ󥯥⥸塼<br />(mylinksweblinksȤޤ)');
define('_MB_WEBLOG_EDIT_LINKS_NUMBER', 'ɽ󥯤ο');
define('_MB_WEBLOG_EDIT_LINKS_ONLYPOST', 'ƼԤ֥ƤΤɽ(0= , 1=Ϥ)');
define('_MB_WEBLOG_EDIT_LINKS_SHOWDSC', '󥯤ɽ(0= , 1=Ϥ)');
define('_MB_WEBLOG_EDIT_CAT_ORDERBY', '¤ӽ');	// added for category list by hodaka
define('_MB_WEBLOG_EDIT_CAT_TITLE', 'ƥ̾');
define('_MB_WEBLOG_EDIT_CAT_ID', 'ƥID');
define('_MB_WEBLOG_EDIT_SHOW_FORBIDDEN_PICTURE', '桼˥ȥαĤƤʤǤɽ (0=ɽʤ , 1=ɽ )');
define('_MB_WEBLOG_EDIT_SHOW_CONTENTS', 'ƥĤɽ (0=ɽʤ , 1=ɽ )');
define('_MB_WEBLOG_EDIT_TBCENTER_ENTRIES', 'ȥåХå󥿡˺ܤ륨ȥ');
define('_MB_WEBLOG_EDIT_TBCENTER_CONTENTS_NUM', 'ȥåХå󥿡ɽ륳ƥĤʸ');
define('_MB_WEBLOG_EDIT_TBCENTER_CATEGORY', 'ȥåХå󥿡Ȥưƥ̾');
// added for archive list by hodaka
define('_MB_WEBLOG_EDIT_ARCHIVE_NUMBER_PER_PAGE', 'ɽǯο');
define('_MB_WEBLOG_LANG_SORT_ARCHIVE', '¤ؤ');
// added for calendar by hodaka
define('_MB_WEBLOG_LANG_PREVMONTH', '&laquo;');
define('_MB_WEBLOG_LANG_NEXTMONTH', '&raquo;');
define('_MB_WEBLOG_LANG_PREVYEAR', '&laquo;');
define('_MB_WEBLOG_LANG_NEXTYEAR', '&raquo;');
define('_MB_WEBLOG_LANG_PREVMONTH_TITLE', 'η');
define('_MB_WEBLOG_LANG_NEXTMONTH_TITLE', 'η');
define('_MB_WEBLOG_LANG_PREVYEAR_TITLE', 'ǯ');
define('_MB_WEBLOG_LANG_NEXTYEAR_TITLE', 'ǯ');
define('_MB_WEBLOG_LANG_THIS_MONTH_TITLE', 'ηΥ');
define('_MB_WEBLOG_LANG_SUNDAY', '');
define('_MB_WEBLOG_LANG_MONDAY', '');
define('_MB_WEBLOG_LANG_TUESDAY', '');
define('_MB_WEBLOG_LANG_WEDNESDAY', '');
define('_MB_WEBLOG_LANG_THURSDAY', '');
define('_MB_WEBLOG_LANG_FRIDAY', '');
define('_MB_WEBLOG_LANG_SATURDAY', '');

define('_MB_WEBLOG_LANG_TITLE', 'ȥ');
define('_MB_WEBLOG_LANG_ENTRIES', 'ǶΥȥ');
define('_MB_WEBLOG_LANG_AUTHOR', 'ɮ');
define('_MB_WEBLOG_LANG_COMMENTS', 'ȿ');
define('_MB_WEBLOG_LANG_POSTED', '');
define('_MB_WEBLOG_LANG_READS', '');
define('_MB_WEBLOG_LANG_MOREWEBLOGS', '֥');
define('_MB_WEBLOG_LANG_TRACKBACKS', 'ȥåХå'); //eng
define('_MB_WEBLOG_LANG_TB_TITLE', 'ȥ');
define('_MB_WEBLOG_LANG_TB_WEBLOGTITLE', 'ȥåХåȥ');
define('_MB_WEBLOG_LANG_TB_BLOGNAME', '֥̾');
define('_MB_WEBLOG_LANG_TB_POSTED', '');
define('_MB_WEBLOG_LANG_COM_TITLE', '');
define('_MB_WEBLOG_LANG_COM_UNAME', '桼');
define('_MB_WEBLOG_LANG_COM_WEBLOGTITLE', 'ȤΥȥ');
define('_MB_WEBLOG_LANG_COM_POSTED', '');
define('_MB_WEBLOG_LANG_LINKS_FOR','%sΥ');
define('_MB_WEBLOG_LANG_LINKS_FOR_EVERYONE','󥯽');
define('_MB_WEBLOG_LANG_DENOTE_PERMIT','<span style=\'color:#FF0000;font-size:10px\'>*</span>ΥȥϱԲ');

define('_MB_WEBLOG_USERS_SORT_READS', '߷ױ');
define('_MB_WEBLOG_USERS_SORT_UPDATE', 'ǽ');

}
?>
